@@ -27,11 +27,16 @@ except ImportError:
 class ClientException(BaseException):
     pass
 
+class AuthException(BaseException):
+    pass
+
 API_HOST = 'https://nucleo.arcus.io/api/v1'
 
 def _request(path='', method='get', data=None, api_key=None, params={}):
     data = utils.api_request(API_HOST, path, method=method, \
         data=data, api_key=api_key, params={})
+    if data.status_code == 403:
+        raise AuthException('Unauthorized')
     return data
 
 class Client(object):
